bayespy.nodes.Gate
==================

.. currentmodule:: bayespy.nodes

.. autoclass:: Gate

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Gate.__init__
      ~Gate.add_plate_axis
      ~Gate.broadcasting_multiplier
      ~Gate.delete
      ~Gate.get_mask
      ~Gate.get_moments
      ~Gate.get_shape
      ~Gate.has_plotter
      ~Gate.lower_bound_contribution
      ~Gate.move_plates
      ~Gate.plot
      ~Gate.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Gate.plates
      ~Gate.plates_multiplier
   
   